/**
 * IMPORTANT: Changes in this file MUST be synced with edge-react-gui!
 */
import * as React from 'react';
import { View } from 'react-native';
import { styled } from '../hoc/styled';
import { Space } from '../layout/Space';
import { ButtonUi4 } from './ButtonUi4';
const INTER_BUTTON_SPACING_REM = 1;
/**
 * A consistently styled view for displaying button layouts.
 */
export const ButtonsViewUi4 = React.memo(({ absolute = false, fade, primary, secondary, secondary2, tertiary, layout = 'column', parentType }) => {
    const numButtons = [primary, secondary, secondary2, tertiary].filter(key => key != null).length;
    if (numButtons === 1)
        layout = 'solo';
    const spacing = React.createElement(Space, { around: INTER_BUTTON_SPACING_REM / 2 });
    const renderButton = (type, buttonProps) => {
        if (buttonProps == null)
            return null;
        const { label, onPress, disabled, spinner, testID } = buttonProps;
        return (React.createElement(ButtonUi4, { layout: layout, label: label, onPress: onPress, type: type, disabled: disabled, spinner: spinner, testID: testID }));
    };
    return (React.createElement(StyledButtonContainer, { absolute: absolute, layout: layout, parentType: parentType },
        renderButton('primary', primary),
        primary != null && secondary != null ? spacing : null,
        renderButton('secondary', secondary2),
        secondary != null && secondary2 != null ? spacing : null,
        renderButton('secondary', secondary),
        tertiary != null ? spacing : null,
        renderButton('tertiary', tertiary)));
});
const StyledButtonContainer = styled(View)(theme => props => {
    const { absolute, layout, parentType } = props;
    const marginSize = theme.rem(0.5);
    const baseStyle = {
        margin: marginSize
    };
    const absoluteStyle = absolute
        ? {
            position: 'absolute',
            bottom: 0,
            left: marginSize,
            right: marginSize
        }
        : {};
    const soloStyle = layout === 'solo'
        ? {
            justifyContent: 'center',
            marginHorizontal: theme.rem(0.5),
            alignItems: 'center',
            flex: 1
        }
        : {};
    const rowStyle = layout === 'row'
        ? {
            flex: 1,
            flexDirection: 'row-reverse',
            justifyContent: 'center'
        }
        : {};
    const columnStyle = layout === 'column'
        ? {
            alignSelf: 'center',
            alignItems: 'stretch',
            flexDirection: 'column',
            justifyContent: 'space-between'
        }
        : {};
    const sceneMarginStyle = parentType === 'scene'
        ? {
            marginBottom: theme.rem(3),
            marginTop: theme.rem(1)
        }
        : {};
    const modalMarginStyle = parentType === 'modal'
        ? {
            marginBottom: theme.rem(1),
            marginTop: theme.rem(2)
        }
        : {};
    return Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign(Object.assign({}, baseStyle), absoluteStyle), soloStyle), rowStyle), columnStyle), sceneMarginStyle), modalMarginStyle);
});
